datablock StaticShapeData(MineDep1Image) : StaticShapeDamageProfile {
	className = "minedep";
	shapeFile = "Brock8.dts";

	maxDamage      = 0.5;
	destroyedLevel = 0.5;
	disabledLevel  = 0.3;

	isShielded = true;
	energyPerDamagePoint = 240;
	maxEnergy = 50;
	rechargeRate = 0.25;

	explosion    = HandGrenadeExplosion;
	expDmgRadius = 3.0;
	expDamage    = 0.1;
	expImpulse   = 200.0;

	dynamicType = $TypeMasks::StaticShapeObjectType;
	deployedObject = true;
	cmdCategory = "DSupport";
	cmdIcon = CMDSensorIcon;
	cmdMiniIconName = "commander/MiniIcons/com_deploymotionsensor";
	targetNameTag = 'Gold';
	deployAmbientThread = true;
	debrisShapeName = "debris_generic_small.dts";
	debris = DeployableDebris;
	heatSignature = 0;
	needsPower = true;
};

datablock ItemData(MineDepPack) {
	className = Pack;
	catagory = "Deployables";
	shapeFile = "stackable4l.dts";
	mass = 5.0;
	elasticity = 0.2;
	friction = 0.6;
	pickupRadius = 1;
	rotate = true;
	image = "MineDepImage";
	pickUpName = "a mining pack";
	heatSignature = 0;
	emap = true;
 };

function MineDepPack::onPickup(%this, %obj, %shape, %amount) {
	// created to prevent console errors
}

function MineDepImage::onDeploy(%item, %plyr, %slot) {

	%playerVector = vectorNormalize(-1 * getWord(%plyr.getEyeVector(),1) SPC getWord(%plyr.getEyeVector(),0) SPC "0");
	%item.surfaceNrm2 = %playerVector;
	%rot = fullRot(%item.surfaceNrm,%item.surfaceNrm2);

	%deplObj = new StaticShape()
    {
	   dataBlock = "MineDep1";
       scale = "2.5 2.5 2.5";
	};

	// set orientation
	%deplObj.setTransform(%item.surfacePt SPC %rot);

	// set the recharge rate right away
	if (%deplObj.getDatablock().rechargeRate)
		%deplObj.setRechargeRate(%deplObj.getDatablock().rechargeRate);

	// set team, owner, and handle
	%deplObj.team = %plyr.client.Team;
	%deplObj.setOwner(%plyr);

	// place the deployable in the MissionCleanup/Deployables group (AI reasons)
	addToDeployGroup(%deplObj);

	//let the AI know as well...
	AIDeployObject(%plyr.client, %deplObj);

	// play the deploy sound
	serverPlay3D(%item.deploySound, %deplObj.getTransform());

	// increment the team count for this deployed object
	$TeamDeployedCount[%plyr.team, %item.item]++;

	addDSurface(%item.surface,%deplObj);
	%deplObj.powerFreq = %plyr.powerFreq;
        checkPowerObject(%deplObj);
        if (!%plyr.client.isAdmin)
        {
           if($Host::ExpertMode == 0) {
              %plyr.unmountImage(%slot);
	          %plyr.decInventory(%item.item, 1);
           }
        }


	return %deplObj;
}

function MineDep::onDestroyed(%this,%obj,%prevState) {
	if (%obj.isRemoved)
		return;
	%obj.isRemoved = true;
	Parent::onDestroyed(%this,%obj,%prevState);
	$TeamDeployedCount[%obj.team, MineDepPack]--;
	remDSurface(%obj);
	%obj.schedule(500, "delete");
}

function MineDepImage::onMount(%data, %obj, %node) {
    displayPowerFreq(%obj);
	%obj.hasMinePack = true;
	%obj.packSet = 0;;
}

function MineDepImage::onUnmount(%data, %obj, %node) {
	%obj.hasMinePack = "";e
	%obj.packSet = 0;
}

function MineDep::DamageObject(%data,%this,%sourceObject,%position,%amount,%damageType)
{
   %miningMoney = 2;
   if(%damageType == $DamageType::MinerGun)
   {
      %sourceObject.money = %sourceObject.money + %miningMoney;
      MessageClient(%sourceObject.client,'msgClient',"Mined gold for $"@%miningMoney@" credits.");
   }
   Parent::DamageObject(%data,%this,%sourceObject,%position,%amount,%damageType);
}
